@@ -22,12 +22,12 @@
 
 #include <QDir>
 #include <QFileInfo>
+#include <QRandomGenerator>
 #include <QStandardPaths>
 
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <KRandom>
 #include "lskat_debug.h"
 
 // KConfig entries
@@ -54,7 +54,7 @@ public:
 
         // Add SVG card sets
         QStringList list;
-        const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "carddecks", QStandardPaths::LocateDirectory);
+        const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("carddecks"), QStandardPaths::LocateDirectory);
         for (const QString& dir : dirs) {
             const QStringList deckFolderNames = QDir(dir).entryList(QStringList() << QStringLiteral("svg*"));
             for (const QString& deck : deckFolderNames) {
@@ -145,7 +145,7 @@ QString randomDeckName()
     // Collect matching items
     QStringList list = deckinfoStatic->themeNameMap.keys();
     // Draw random one
-    int d = KRandom::random() % list.count();
+    int d = QRandomGenerator::system()->bounded(list.count());
     return list.at(d);
 }
 
